add_astrometry — MSUMastro toolbox 0.1 documentation

# add_astrometry

`msumastro.header_processing.astrometry.` `add_astrometry`(filename, overwrite=False, ra_dec=None, note_failure=False, save_wcs=False, verify=None, try_builtin_source_finder=False)

  Add WCS headers to FITS file using astrometry.net

  Parameters: | overwrite : bool, optional Set `True` to overwrite the original file. If False, the file astrometry.net generates is kept. ra_dec : list or tuple of float or str (RA, Dec) of field center as either decimal or sexagesimal; also limits search radius to 1 degree. note_failure : bool, optional If `True`, create a file with extension “failed” if astrometry.net fails. The “failed” file contains the error messages genreated by astrometry.net. try_biultin_source_finder : bool If true, try using astrometry.net’s built-in source extractor if sextractor fails. save_wcs : verify : See `call_astrometry()`
  Returns: | bool `True` on success.

  Notes

  Tries a couple strategies before giving up: first sextractor, then, if that fails, astrometry.net’s built-in source extractor.

  It also cleans up after astrometry.net, keeping only the new FITS file it generates, the .solved file, and, if desired, a ”.failed” file for fields which it fails to solve.

  For more flexible invocation of astrometry.net, see `call_astrometry()`